@@ -71,15 +71,15 @@ Schmildt <- function(.data, env, gen, rep, resp, prob = 0.05,
   }
   for (var in 1:nvar) {
     data <- factors %>%
-      mutate(mean = vars[[var]])
+      mutate(Y = vars[[var]])
     environments <-
       data %>%
       means_by(ENV, na.rm = TRUE) %>%
-      add_cols(index = mean - mean(mean),
+      add_cols(index = Y - mean(Y),
                class = ifelse(index < 0, "unfavorable", "favorable")) %>%
       as_tibble()
     data <- left_join(data, environments %>% select(ENV, class), by = "ENV")
-    mat_g <- make_mat(data, row = GEN, col = ENV, value = mean)
+    mat_g <- make_mat(data, row = GEN, col = ENV, value = Y)
     rp_g <- sweep(mat_g, 2, colMeans(mat_g, na.rm = TRUE), "/") * 100
     Wi_g <- rowMeans(rp_g, na.rm = TRUE) - qnorm(1 - prob) * apply(rp_g, 1, sem, na.rm = TRUE)
     general <- tibble(GEN = rownames(mat_g),
@@ -89,7 +89,7 @@ Schmildt <- function(.data, env, gen, rep, resp, prob = 0.05,
                       Wi = Wi_g,
                       rank = rank(-Wi_g))
     ge_mf <- subset(data, class == "favorable")
-    mat_f <- dplyr::select_if(make_mat(ge_mf, row = GEN, col = ENV, value = mean), function(x) !any(is.na(x)))
+    mat_f <- dplyr::select_if(make_mat(ge_mf, row = GEN, col = ENV, value = Y), function(x) !any(is.na(x)))
     rp_f <- sweep(mat_f, 2, colMeans(mat_f, na.rm = TRUE), "/") * 100
     Wi_f <- rowMeans(rp_f, na.rm = TRUE) - qnorm(1 - prob) * apply(rp_f, 1, sem, na.rm = TRUE)
     favorable <- tibble(GEN = rownames(mat_f),
@@ -99,7 +99,7 @@ Schmildt <- function(.data, env, gen, rep, resp, prob = 0.05,
                         Wi = Wi_f,
                         rank = rank(-Wi_f))
     ge_mu <- subset(data, class == "unfavorable")
-    mat_u <- dplyr::select_if(make_mat(ge_mu, row = GEN, col = ENV, value = mean), function(x) !any(is.na(x)))
+    mat_u <- dplyr::select_if(make_mat(ge_mu, row = GEN, col = ENV, value = Y), function(x) !any(is.na(x)))
     rp_u <- sweep(mat_u, 2, colMeans(mat_u, na.rm = TRUE), "/") * 100
     Wi_u <- rowMeans(rp_u, na.rm = TRUE) - qnorm(1 - prob) * apply(rp_u, 1, sem, na.rm = TRUE)
     unfavorable <- tibble(GEN = rownames(mat_u),
